from click.types import IntParamType

from kudu.api import request as api_request


class PitcherFileType(IntParamType):
    name = 'pitcher-file'

    def __init__(self, category=None):
        self.category = category

    def convert(self, value, param, ctx):
        value = super(PitcherFileType, self).convert(value, param, ctx)

        res = api_request('get', '/files/%d/' % value, token=ctx.obj['token'])
        if res.status_code != 200:
            self.fail('%d is not a valid file' % value)

        data = res.json()
        if self.category and data.get('category') not in self.category:
            self.fail('%d is not of a valid file category' % value)

        return data



import os

from click.testing import CliRunner

from kudu.__main__ import cli
from kudu.api import authenticate
from kudu.api import request as api_request


def test_push_zip():
    runner = CliRunner()
    with runner.isolated_filesystem():
        token = authenticate(os.environ['KUDU_USERNAME'], os.environ['KUDU_PASSWORD'])
        creation_time = api_request('get', '/files/%d/' % 519655, token=token).json()['creationTime']

        open('index.html', 'a').close()
        open('thumbnail.png', 'a').close()
        result = runner.invoke(cli, ['push', '-f', 519655])
        assert result.exit_code == 0

        result = runner.invoke(cli, ['pull', '-f', 519655])
        assert result.exit_code == 0
        assert os.path.exists(os.path.join('519655_1549795523377', 'index.html'))
        assert os.path.exists(os.path.join('519655_1549795523377', '519655_1549795523377.png'))
        assert creation_time != api_request('get', '/files/%d/' % 519655, token=token).json()['creationTime']


def test_push_json():
    runner = CliRunner()
    with runner.isolated_filesystem():
        result = runner.invoke(cli, ['push', '-f', 519631])
        assert result.exit_code == 2



import os
import re
import subprocess

import click


def default_pitcher_folders():
    click.echo('Your Pitcher Folders are configured automatically based on your iOS simulator devices. Please check '
               'that they are accurate. You can suppress this message by setting them explicitly. Run the following '
               'command and follow the instructions in your editor to edit your configuration file:\n\n'
               '\tkudu config --global --edit\n')

    ios_sim_devices = []

    try:
        instruments_output = subprocess.check_output(['instruments', '-s', 'devices']).splitlines()
        prog = re.compile(r"iPad .+\[([^\]]+)")
        devices_path = os.path.expanduser('~/Library/Developer/CoreSimulator/Devices/')

        for line in instruments_output:
            prog_match = prog.match(line)
            if prog_match:
                device_guid = prog_match.group(1)
                find_output = subprocess.check_output(
                    ['find', os.path.join(devices_path, device_guid), '-name', 'Pitcher Folders']).strip()
                if find_output:
                    ios_sim_devices.append({'name': line, 'guid': device_guid, 'pitcher_folders': find_output})
    except OSError:
        pass

    if len(ios_sim_devices) > 0:
        ios_sim_device_index = 0

        if len(ios_sim_devices) > 1:
            for key, device in enumerate(ios_sim_devices):
                click.echo('%d. %s' % (key + 1, device['name']))
            ios_sim_device_index = int(click.prompt('Please select a device', type=click.Choice(
                [str(key + 1) for key, device in enumerate(ios_sim_devices)]))) - 1

        return ios_sim_devices[ios_sim_device_index]['pitcher_folders']



from os.path import join, exists

from click.testing import CliRunner

from kudu.__main__ import cli
from kudu.config import write_config


def test_pull_file():
    runner = CliRunner()
    with runner.isolated_filesystem():
        result = runner.invoke(cli, ['pull', '-f', 519629])
        assert result.exit_code == 0
        assert exists(join('519629_1549718939', 'index.html'))
        assert exists(join('519629_1549718939', '519629_1549718939.png'))
        assert exists(join('519629_1549718939', 'folder', 'foobar.json'))


def test_pull_project():
    runner = CliRunner()
    with runner.isolated_filesystem():
        write_config({'file_id': 519629})
        result = runner.invoke(cli, ['pull'])
        assert result.exit_code == 0
        assert exists('index.html')
        assert exists('thumbnail.png')
        assert exists(join('folder', 'foobar.json'))


def test_interface():
    runner = CliRunner()
    with runner.isolated_filesystem():
        write_config({'file_id': 527702})
        result = runner.invoke(cli, ['pull'])
        assert result.exit_code == 0
        assert exists(join('interface', 'index.html'))
        assert exists(join('interface_1', 'index.html'))
        assert exists(join('lang', 'AR.csv'))



from os.path import expanduser

import click
import yaml


def write_config(data, path='.kudu.yml'):
    with open(path, 'w+') as stream:
        yaml.safe_dump(data, stream, default_flow_style=False, allow_unicode=True)


def read_config(path='.kudu.yml'):
    try:
        with open(path, 'r+') as stream:
            try:
                from yaml import CLoader as Loader, CDumper as Dumper
            except ImportError:
                from yaml import Loader, Dumper

            config = yaml.load(stream.read(), Loader=Loader)
    except IOError:
        config = {}

    return config


def merge_config(self, other):
    if isinstance(other, dict):
        for key, value in other.items():
            self[key] = value


def load_config():
    config = {}

    for path in (expanduser('~/.kudu.yml'), '.kudu.yml'):
        merge_config(config, read_config(path))

    return config


class ConfigOption(click.Option):
    data = None

    def __init__(self, param_decls=None, config_name=None, **attrs):
        click.Option.__init__(self, param_decls, **attrs)
        self.config_name = config_name if config_name else self.name

    def consume_value(self, ctx, opts):
        value = super(ConfigOption, self).consume_value(ctx, opts)
        if value is None:
            value = load_config().get(self.config_name)
        return value



#!/usr/bin/env python

import click

from kudu.api import authenticate
from kudu.commands.init import init
from kudu.commands.link import link
from kudu.commands.pull import pull
from kudu.commands.push import push
from kudu.config import ConfigOption


@click.group()
@click.option('--username', '-u', cls=ConfigOption, prompt=True, envvar='KUDU_USERNAME')
@click.option('--password', '-p', cls=ConfigOption, prompt=True, hide_input=True, envvar='KUDU_PASSWORD')
@click.option('--token', '-t', cls=ConfigOption, envvar='KUDU_TOKEN')
@click.pass_context
def cli(ctx, username, password, token):
    if not token:
        try:
            token = authenticate(username, password)
        except ValueError:
            click.echo('Invalid username or password', err=True)
            exit(1)

    ctx.obj = {
        'username': username,
        'password': password,
        'token': token
    }


cli.add_command(init)
cli.add_command(pull)
cli.add_command(push)
cli.add_command(link)

if __name__ == '__main__':
    cli()



import os
import zipfile
from os import remove, walk
from os.path import splitext, join, exists, isdir, relpath
from shutil import copyfileobj, move, rmtree

import click
import requests

from kudu.api import request as api_request
from kudu.config import ConfigOption
from kudu.types import PitcherFileType


def move_dir(src, dst):
    for root, dirs, files in walk(src):
        for name in files:
            arcroot = join(dst, relpath(root, src))
            if not exists(arcroot):
                os.makedirs(arcroot)
            move(join(root, name), join(arcroot, name))
    rmtree(src)


def move_thumb(root):
    filename = root + '.png'
    if exists(filename):
        move(filename, 'thumbnail.png')


@click.command()
@click.option('--file', '-f', 'pfile',
              cls=ConfigOption, config_name='file_id',
              prompt='File ID', type=PitcherFileType())
@click.pass_context
def pull(ctx, pfile):
    download_url = api_request('get', '/files/%d/download-url/' % pfile['id'], token=ctx.obj['token']).json()

    with open(pfile['filename'], 'w') as stream:
        r = requests.get(download_url, stream=True)
        copyfileobj(r.raw, stream)

    root, ext = splitext(pfile['filename'])
    if ext == '.zip':
        with zipfile.ZipFile(pfile['filename'], 'r') as stream:
            stream.extractall()
        remove(pfile['filename'])

        if exists('.kudu.yml') and isdir(root):
            move_dir(root, os.curdir if pfile['category'] else 'interface')
            move_thumb(root)



from setuptools import setup, find_packages

from kudu import __author__
from kudu import __email__
from kudu import __version__

setup(
    name='kudu',
    author=__author__,
    author_email=__email__,
    version=__version__,
    description='A deployment command line program in Python.',
    url='https://github.com/torfeld6/kudu',
    license='BSD',
    classifiers=[
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    keywords='cli',
    packages=find_packages(),
    install_requires=['requests>=2.20.1', 'PyYAML', 'GitPython', 'watchdog', 'click'],
    entry_points={
        'console_scripts': [
            'kudu = kudu.__main__:cli',
        ],
    },
)



import os
import tempfile
import zipfile
from datetime import datetime

import click
import requests

from kudu.api import request as api_request
from kudu.config import ConfigOption
from kudu.types import PitcherFileType


@click.command()
@click.option('--file', '-f', 'pfile',
              cls=ConfigOption, config_name='file_id',
              prompt=True, type=PitcherFileType(category=('zip', 'presentation')))
@click.pass_context
def push(ctx, pfile):
    chroot, ext = os.path.splitext(pfile['filename'])

    with tempfile.NamedTemporaryFile() as tf:
        zf = zipfile.ZipFile(tf.name, 'w', zipfile.ZIP_DEFLATED)
        for root, dirs, files in os.walk(os.getcwd()):
            arcroot = os.path.relpath(root)
            for name in files:
                arcname = name if not (arcroot == os.curdir and name == 'thumbnail.png') else chroot + '.png'
                zf.write(os.path.join(root, name), os.path.join(chroot, arcroot, arcname))
        zf.close()

        upload_url = api_request('get', '/files/%d/upload-url/' % pfile['id'], token=ctx.obj['token']).json()
        requests.put(upload_url, data=tf)

    api_request('patch', '/files/%d/' % pfile['id'], json={'creationTime': datetime.utcnow().isoformat()},
                token=ctx.obj['token'])
